<?php
/*
Description: Easy adverts
Version: 1.0
Author: Matcha Labs
*/

class ML_Adverts_Advert
{
	private $advert_id;

	/**
	 * Construct
	 */
	function __construct($advert_id) {
		$this->set_advert_id($advert_id);
	}

	/**
	 * Return the advert ID
	 */
	public function get_advert_id() {
		return $this->advert_id;
	}

	/**
	 * Set the advert ID
	 */
	public function set_advert_id($id) {
		$this->advert_id = $id;
	}

	/**
	 * Get metadata for advert
	 */
	public function get_meta($key) {
		return get_post_meta($this->get_advert_id(), 'ml_advert_' . $key, true);
	}

	/**
	 * Find and return the banner HTML or Image
	 */
	public function get_code() {
        if ($this->get_meta('type') == 'html') {
            $ret_val = $this->get_html();
        } else {
            $ret_val = $this->get_image();
        }

        return $ret_val;
	}

	/**
	 * Return css class string
	 */
	public function get_css_class() {
		return "ml-adverts-" . $this->get_advert_id();
	}

	/**
	 * Return the advert image markup
	 */
	private function get_image() {
	    $url_mask = $this->get_meta('url_mask');

	    if ($url_mask == '') {
	        $url_mask = $this->get_meta('url');
	    }

	    $ret_val = "<a" .
	                   " href='" . MLA_BASE_URL . "out.php?id=" . $this->get_advert_id() . "'" . 
	                   " onmouseover='maskLink(this,event,\"" . $url_mask . "\")'" .
	                   " onclick='maskLink(this,event,\"" . $url_mask . "\")'" . 
	                   " onmouseout='maskLink(this,event,\"" . $url_mask . "\")'" .
	                   " target='_blank' />";

	    $ret_val .= "<img src='" . $this->get_meta('image') . "' />";
	    $ret_val .= "</a>";

	    return $ret_val;
	}


	/**
	 * Return the advert HTML
	 */
	private function get_html() {
	    return html_entity_decode($this->get_meta('html'));
	}

	/**
	 *
	 */
	public function is_active() {
      	$location = get_the_terms( $this->get_advert_id(), 'ml-adverts-location');

      	$errors = array();

      	if (count($location) == 0 || !$location) {
      		$errors[] = "Not tagged to location";
      	}

      	if ($this->get_meta('pages') == '' && $this->get_meta('post_types') == '') {
      		$errors[] = "Not set to display on any posts or pages";
      	}

      	if ($this->get_meta('start_date') == '') {
      		$errors[] = "Start date not set";
      	} else if ($this->get_meta('start_date') > time()) {
      		$errors[] = "Start date is in the future";
      	}

      	if ($this->get_meta('end_date') == '') {
      		$errors[] = "End date not set";
      	} else if ($this->get_meta('end_date') < time()) {
      		$errors[] = "End date has passed (banner expired)";
      	}

      	if (get_post_status($this->get_advert_id()) != 'publish') {
      		$errors[] = "Advert is not published";
      	}

      	return $errors;
	}

	/**
	 *
	 */
	public function increment_impressions() {
		$this->record_stat('impression');
	}

	/**
	 *
	 */
	public function increment_clicks() {
		$this->record_stat('click');
	}

	/**
	 *
	 */
	public function get_stat($type = 'click') {
		global $wpdb;

		$wpdb->get_results( 
			"SELECT id FROM " . $wpdb->prefix . "ml_adverts_stats
			WHERE type = '" . $type . "' AND advert_id = " . $this->get_advert_id()
		);

		$num_rows = $wpdb->num_rows;

		wp_reset_query();
		
		return $num_rows;
	}
	/**
	 * Record a click or impression against an advert
	 */
	private function record_stat($type = 'impression') {
		global $wpdb;

		$user_agent = mysql_real_escape_string($_SERVER["HTTP_USER_AGENT"]);

		$wpdb->insert( 
			$wpdb->prefix . 'ml_adverts_stats', array( 
				'advert_id' => $this->get_advert_id(), 
				'type' => $type,
				'user_agent' => $user_agent,
				'time' => current_time('mysql')
			)
		);
	}
}